@@ -5,6 +5,7 @@ from . import account
 from . import availability_rule
 from . import base
 from . import brand
+from . import bulk_order
 from . import compose
 from . import config
 from . import country_group
@@ -22,11 +23,13 @@ from . import root
 from . import size
 from . import sku
 from . import transport_rule
+from . import video
 
 from .account import AccountAPI
 from .availability_rule import AvailabilityRuleAPI
 from .base import API
 from .brand import BrandAPI
+from .bulk_order import BulkOrderAPI
 from .country_group import CountryGroupAPI
 from .compose import ComposeAPI
 from .config import ConfigAPI
@@ -44,3 +47,4 @@ from .root import RootAPI
 from .size import SizeAPI
 from .sku import SkuAPI
 from .transport_rule import TransportRuleAPI
+from .video import VideoAPI
